of_graph_get_next_endpoint() is now renamed to
of_graph_get_next_device_endpoint(). Switch to it.

Signed-off-by: Kuninori Morimoto <kuninori.morimoto...@renesas.com>
---
 drivers/hwtracing/coresight/coresight-platform.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/hwtracing/coresight/coresight-platform.c 
b/drivers/hwtracing/coresight/coresight-platform.c
index 9d550f5697fa..944b2e66c04e 100644
--- a/drivers/hwtracing/coresight/coresight-platform.c
+++ b/drivers/hwtracing/coresight/coresight-platform.c
@@ -275,7 +275,7 @@ static int of_get_coresight_platform_data(struct device 
*dev,
         */
        if (!parent) {
                /*
                 * Avoid warnings in of_graph_get_next_endpoint()
                 * if the device doesn't have any graph connections
                 */
                if (!of_graph_is_present(node))
@@ -286,7 +286,7 @@ static int of_get_coresight_platform_data(struct device 
*dev,
        }
 
        /* Iterate through each output port to discover topology */
-       while ((ep = of_graph_get_next_endpoint(parent, ep))) {
+       while ((ep = of_graph_get_next_device_endpoint(parent, ep))) {
                /*
                 * Legacy binding mixes input/output ports under the
                 * same parent. So, skip the input ports if we are dealing
@@ -275,7 +275,7 @@ static int of_get_coresight_platform_data(struct device 
        if (!parent) {
                /*
-                * Avoid warnings in of_graph_get_next_endpoint()
+                * Avoid warnings in of_graph_get_next_device_endpoint()
                 * if the device doesn't have any graph connections
                 */
-- 
2.25.1

Reply via email to